@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.12";
+our $VERSION = "0.20";
 
 use Carp qw/croak/;
 use DBIx::TransactionManager;
@@ -189,7 +189,6 @@ sub _load_fixture_from_data {
     my $delete = $self->delete || $args{delete};
 
     $data = $self->_normalize_data($data);
-    return unless @$data;
 
     my $dbh = $self->dbh;
     # needs limit ?
@@ -200,6 +199,8 @@ sub _load_fixture_from_data {
         $dbh->do($sql, undef, @binds);
     }
 
+    return $txn->commit or croak $dbh->errstr unless scalar @$data;
+
     my $opt; $opt->{prefix} = 'INSERT IGNORE INTO' if $ignore;
     if ($bulk_insert) {
         $opt->{update} = _build_on_duplicate(keys %{$data->[0]}) if $update;
@@ -257,7 +258,7 @@ DBIx::FixtureLoader - Loading fixtures and inserting to your database
 
     use DBI;
     use DBIx::FixtureLoader;
-    
+
     my $dbh = DBI->connect(...);
     my $loader = DBIx::FixtureLoader->new(dbh => $dbh);
     $loader->load_fixture('item.csv');
